@@ -7,7 +7,7 @@ from sha import sha
 from webob import Request, Response
 from simplejson import loads, dumps, JSONEncoder
 
-from jsonstore.store import EntryManager
+from jsonstore.store import EntryManager, ConflictError
 from jsonstore import rison
 from jsonstore import operators
 
@@ -76,7 +76,10 @@ class JSONStore(object):
 
     def POST(self, req):
         entry = load_entry(req.body)
-        result = self.em.create(entry)
+        try:
+            result = self.em.create(entry)
+        except ConflictError:
+            return Response(status='409 Conflict')
         body = dumps(result, cls=DatetimeEncoder)
         etag = '"%s"' % sha(body).hexdigest()
         location = urljoin(req.application_url, result['__id__'])
